+++++++++
Changelog
+++++++++


0.5.0 (26-05-2022)
==================

- Improvements in dependency detections
- Include uncommited changes in sdists


0.4.0 (06-05-2022)
==================

- Set sane default arguments for release builds


0.3.0 (23-03-2022)
==================

- Initial cross-platform support
  - Bundling libraries stioll is only supported on Linux
- Add initial documentation
- The build directory is now located in the project source


0.2.1 (26-02-2022)
==================

- Fix getting the project version dynamically from Meson


0.2.0 (24-01-2022)
==================

- Select the correct ABI and Python tags
- Force Meson to use the correct Python executable
- Replace auditwheel with in-house vendoring mechanism


0.1.2 (12-11-2021)
==================

- Fix auditwheel not being run


0.1.1 (28-10-2021)
==================

- Fix minor compability issue with Python < 3.9


0.1.0 (28-10-2021)
==================

- Initial release
